@@ -9,14 +9,15 @@
  */
 
 #include <sys/types.h>
+#include <sys/param.h>
 #include <sys/module.h>
 #include <sys/errno.h>
-#include <sys/param.h>
 #include <sys/kernel.h>
 #include <sys/malloc.h>
 #include <sys/ioccom.h>
 #include <sys/libkern.h>
 #include <sys/lock.h>
+#include <sys/mutex.h>
 #include <sys/sx.h>
 #include <sys/conf.h>
 #include <sys/syslog.h>
@@ -31,6 +32,8 @@
 #include "nvkms.h"
 #include "nv-modeset-interface.h"
 
+#include "nv-retpoline.h"
+
 /*
  * This option decides if nvidia-modeset.ko will be built with support
  * for Linux or Linux 32-bit (FreeBSD/amd64) compatibility.  This
@@ -566,7 +569,11 @@ void NVKMS_API_CALL nvkms_get_random(void *ptr, size_t size)
 
 #if NV_FGET_HAS_CAP_RIGHTS_T_ARG
   #include <sys/caprights.h>
-  #include <sys/capability.h>
+  #if __FreeBSD_version >= 1100012
+    #include <sys/capsicum.h>
+  #else
+    #include <sys/capability.h>
+  #endif
 #endif
 
 /*
@@ -774,7 +781,6 @@ static int nvkms_ioctl(
     sx_xlock(&nvkms_lock);
     ret = nvKmsIoctl(popen->data,
                      params->cmd,
-                     NVKMS_CLIENT_USER_SPACE,
                      params->address,
                      params->size);
     sx_xunlock(&nvkms_lock);
@@ -821,7 +827,7 @@ static int nvkms_open(
     mtx_init(&popen->events.lock, "nvkms-events-lock", NULL, 0);
 
     sx_xlock(&nvkms_lock);
-    popen->data = nvKmsOpen(popen);
+    popen->data = nvKmsOpen(curproc->p_pid, NVKMS_CLIENT_USER_SPACE, popen);
     sx_xunlock(&nvkms_lock);
 
     /*
