@@ -21,8 +21,11 @@
 
 #include <sys/param.h>
 
-#if __FreeBSD_version >= 1300000
-#error This driver does not support FreeBSD 13.x/-CURRENT!
+#if __FreeBSD_version >= 1400000
+#error This driver does not support FreeBSD 14.x/-CURRENT!
+#endif
+#if __FreeBSD_version >= 1300000 && __FreeBSD_version < 1300139
+#error This driver requires FreeBSD 13.0-RC1 or later!
 #endif
 #if __FreeBSD_version >= 1200000 && __FreeBSD_version < 1200086
 #error This driver requires FreeBSD 12.0-RC3 or later!
@@ -467,9 +470,9 @@ int    nvidia_close_ctl      (nv_state_t *, struct nvidia_filep *);
 int    nvidia_close_dev      (nv_state_t *, struct nvidia_filep *);
 void   nvidia_close_dev_kernel(NvU32 gpu_id, nvidia_stack_t *sp);
 int    nvidia_mmap_ctl_single(nv_state_t *, struct nvidia_filep *, vm_ooffset_t *,
-        vm_size_t, vm_object_t *);
+        vm_size_t, vm_object_t *, int nprot);
 int    nvidia_mmap_dev_single(nv_state_t *, struct nvidia_filep *, vm_ooffset_t *,
-        vm_size_t, vm_object_t *);
+        vm_size_t, vm_object_t *, int nprot);
 
 /* nvidia_modeset_interface.c */
 void   nvidia_modeset_suspend(NvU32 gpu_id);
