@@ -1456,7 +1456,8 @@ int nvidia_mmap_ctl_single(
     struct nvidia_filep *filep,
     vm_ooffset_t *offset,
     vm_size_t size,
-    vm_object_t *object
+    vm_object_t *object,
+    int nprot
 )
 {
     struct nvidia_alloc *at;
@@ -1490,6 +1491,12 @@ int nvidia_mmap_ctl_single(
     pageIndex = mmap_context->page_index;
     prot = mmap_context->prot;
 
+    if ((prot & nprot) != nprot)
+    {
+        rm_release_api_lock(sp);
+        return -EACCES;
+    }
+
     vm_object_reference(at->object);
     *object = at->object;
     *offset = (pageIndex * PAGE_SIZE);
@@ -1504,7 +1511,8 @@ int nvidia_mmap_dev_single(
     struct nvidia_filep *filep,
     vm_ooffset_t *offset,
     vm_size_t size,
-    vm_object_t *object
+    vm_object_t *object,
+    int nprot
 )
 {
     struct nvidia_softc *sc = nv->os_state;
@@ -1523,6 +1531,11 @@ int nvidia_mmap_dev_single(
     *offset = mmap_context->mmap_start;
     size = mmap_context->mmap_size;
 
+    if ((mmap_context->prot & nprot) != nprot)
+    {
+        return -EACCES;
+    }
+
     if (IS_UD_OFFSET(nv, *offset, size)) {
         *object = sc->UD_object;
         vm_object_reference(*object);
